function A = normu(u);

% NORMU Normalizes points to be used for LS estimation.
%       A = NORMU(u) finds normalization matrix A so that mean(A*u)=0 and std(A*u)=1
%       (eg, Hartley: In Defence of 8-point Algorithm, ICCV`95).
%       Parameters:
%         u ... Size (2,1). Points to normalize.
%         A ... Size (3,3). Normalization matrix.
%       Example:
%         For computation of fundamental matrix NORMU can be used as follows:
%           A1 = NORMU(u1); nu1 = p2e(A1*e2p(u1));
%           A2 = NORMU(u2); nu2 = p2e(A2*e2p(u2));
%           nQ = UU2Q(...,nu1,nu2,...);
%           Q = A1'*nQ*A2;
%       See also UU2HOMOG, UU2Q, UUU2T, TNORM2T.

%       Author       : (c) T. Werner and T. Pajdla, {werner,pajdla}@cmp.felk.cvut.cz
%                      07/09/98
%                      Center for Machine Perception, Czech Technical University, Prague
%       Documentation: ftp://cmp.felk.cvut.cz/pub/cmp/articles/werner/tr97-138.ps.gz     
%       Language     : Matlab 5.1, (c) MathWorks                         
%       Last change  : $Id: normu.m,v 1.1 1998/09/07 15:54:15 Matlab Exp $
%       Status       : Ready ($Source: /home.others/Matlab/Matlab/radial/RCS/normu.m,v $)


% (taken over from Tom Svoboda, CMP Prague, Oct 1996)

Xmean = mean(u(1,:)')';
Ymean = mean(u(2,:)')';

%u(1:2,:) = [u(1,:)-Xmean; u(2,:)-Ymean];
Distances = sqrt( ((u(1,:)-Xmean).^2 + (u(2,:)-Ymean).^2) );
Ratio = mean(Distances')'/sqrt(2);

% compute transformation matrices nu'=A*u
A      = diag([1/Ratio,1/Ratio,1]);
A(1,3) = -A(1,1)*Xmean;
A(2,3) = -A(2,2)*Ymean;

%u = u/Ratio;

return
