function Res = objho(Hp,ud,uw,SWAP_DISTFCN)
%objho Objective function for correcting radial lens distortion from scene points known up to 2D-to-2D homography.
%      res = objho(p,ud,uw), where
%        Hp ... Size (?,1). Homography and lens distortion parameters. 
%               It is Hp = [H(:); p]. See rdestim.
%        ud, uw ... See rdestim.
%        Res ... Size (?,1). Residuals of 2D-to-2D homography to ud, uw,
%                where ud were first undistorted by p.

%       Author       : (c) T. Werner and T. Pajdla, {werner,pajdla}@cmp.felk.cvut.cz
%                      07/09/98
%                      Center for Machine Perception, Czech Technical University, Prague
%       Documentation: ftp://cmp.felk.cvut.cz/pub/cmp/articles/werner/tr97-138.ps.gz     
%       Language     : Matlab 5.1, (c) MathWorks                         
%       Last change  : $Id: objho.m,v 1.1 1998/09/07 15:54:15 Matlab Exp $
%       Status       : Ready ($Source: /home.others/Matlab/Matlab/radial/RCS/objho.m,v $)


% extract H and p from Hp
H = reshape(Hp(1:9),3,3);
p = Hp(10:length(Hp));

% compute ue which is the value of ud assuming the estimate H, p
ue = u2udist(p,p2e(H*e2p(uw)),SWAP_DISTFCN);

% compute residuals between ue and ud
Res = ue - ud;

return
