function Res = objln(p,ud,L,SWAP_DISTFCN)
%objln Objective function for correcting radial lens distortion from lines.
%      Res = objln(p,ud,L), where
%        p ... See u2udist.
%        ud, L ... See rdestim.
%        Res ... Size (?,1). Residuals of fitting lines to colinear points,
%                first undistorted by p.

%       Author       : (c) T. Werner and T. Pajdla, {werner,pajdla}@cmp.felk.cvut.cz
%                      07/09/98
%                      Center for Machine Perception, Czech Technical University, Prague
%       Documentation: ftp://cmp.felk.cvut.cz/pub/cmp/articles/werner/tr97-138.ps.gz     
%       Language     : Matlab 5.1, (c) MathWorks                         
%       Last change  : $Id: objln.m,v 1.1 1998/09/07 15:54:15 Matlab Exp $
%       Status       : Ready ($Source: /home.others/Matlab/Matlab/radial/RCS/objln.m,v $)


%%
 % Apply inverse distortion to points ui.
 %%
uu = udist2u(p,ud,SWAP_DISTFCN);

if 1
%%
 % Transform uu by such a homography H that
 %   |H*e2p(uu) - e2p(ud)| ---> min
 % The reason for that is to keep the scales of ud
 % (original, measured points) and uu (undistorted points) similar.
 %%
H = uu2homog(uu,ud,'norm');
uu = p2e(H*e2p(uu));

else
%%
 % Multiply (uu-u0) by such a scale alpha that 
 %   |alpha*(uu-u0) - (ud-u0)| ---> min
 %%
u0 = p(1:2)*ones(1,size(uu,2));
uu0 = uu-u0; ud0 = ud-u0;
uu = u0 + (uu0(:)\ud0(:))*uu0;

end


%%
 % Fit straight lines to uu and
 % use the fit residuals as the return value of OBJLN.
 %%
res = [];
for n = 1:size(L,2)
  Ln = full(L(:,n));       % sparse indices of n-th line points
  uun = uu(:,Ln(Ln~=0));   % n-th line points
  if uun
    [a,resn] = linefit(uun); % fit line, a is not needed
    res = [res resn];
  end
end

%Res = sqrt(sum(res.^2));
Res = res;

return
