function x = p2e(x_)

%P2E  Projective to euclidean coordinates.
%     x = p2e(x_) Computes euclidean coordinates by dividing 
%     all rows but last by the last row.
%       x_ ... Size (dim+1,N) Projective coordinates.
%       x ... Size (dim,N). Euclidean coordinates.
%       (N can be arbitrary.)

%       Author       : (c) T. Werner and T. Pajdla, {werner,pajdla}@cmp.felk.cvut.cz
%                      07/09/98
%                      Center for Machine Perception, Czech Technical University, Prague
%       Documentation: ftp://cmp.felk.cvut.cz/pub/cmp/articles/werner/tr97-138.ps.gz     
%       Language     : Matlab 5.1, (c) MathWorks                         
%       Last change  : $Id: p2e.m,v 1.1 1998/09/07 15:54:15 Matlab Exp $
%       Status       : Ready ($Source: /home.others/Matlab/Matlab/radial/RCS/p2e.m,v $)


if isempty(x_)
  x = []; 
  return; 
end
dim = size(x_,1) - 1;
x = x_(1:dim,:) ./ (ones(dim,1)*x_(dim+1,:));
