function p = psimi2p(p,A)

%PSIMI2P  Applies similitude transformation to lens radial distortion parameters.
%         p2 = psimi2p(p1,A), where
%           A ... Size (3,3). Similarity transformation matrix. It must be 
%                 A(3,1:2)=[0 0] and A(1:2,1:2) orthogonal.
%           p1, p2 ... Size (?,1). Lens radial distortion parameters, eg, p1=[u0; r0; k].
%                      See R2RDIST for details.
%
%         See also R2RDIST, rdestim, NORMU.

%       Author       : (c) T. Werner and T. Pajdla, {werner,pajdla}@cmp.felk.cvut.cz
%                      07/09/98
%                      Center for Machine Perception, Czech Technical University, Prague
%       Documentation: ftp://cmp.felk.cvut.cz/pub/cmp/articles/werner/tr97-138.ps.gz     
%       Language     : Matlab 5.1, (c) MathWorks                         
%       Last change  : $Id: psimi2p.m,v 1.1 1998/09/07 15:54:15 Matlab Exp $
%       Status       : Ready ($Source: /home.others/Matlab/Matlab/radial/RCS/psimi2p.m,v $)


A = A/A(3,3);

% image center
p(1:2) = p2e(A*e2p(p(1:2)));

% scale
sc = sqrt(abs(det(A(1:2,1:2))));

% scale r0
p(3) = p(3)*sc;

% scale k
% k(1) := k(1)/sc^2
% k(2) := k(2)/sc^4
%   ....
ki = 4:length(p);
p(ki) = p(ki) ./ sc.^(2*[1:length(ki)]');


