function rd = r2rdist(r0,k,r,SWAP)
%r2rdist Lens radial distortion applied to an undistorted image point radius.
%        rd = r2rdist(r0,k,r), where
%          r0 ... Size (1,1). Radius in which rd-r==0.
%          k .... Size (kn,1). Coefficients of the lens distortion polynom.
%          r ... Size (1,N). Radius of the undistorted image point.
%          rd ... Size (1,N). Radius of the distorted image point.
%
%        The model of the lens radial distortion:
%          rd = r*(1 + k(1)*(r^2-r0^2) + k(2)*(r^4-r0^4) + ... )
%
%         See also rdist2r.

%       Author       : (c) T. Werner and T. Pajdla, {werner,pajdla}@cmp.felk.cvut.cz
%                      07/09/98
%                      Center for Machine Perception, Czech Technical University, Prague
%       Documentation: ftp://cmp.felk.cvut.cz/pub/cmp/articles/werner/tr97-138.ps.gz     
%       Language     : Matlab 5.1, (c) MathWorks                         
%       Last change  : $Id: r2rdist.m,v 1.1 1998/09/07 15:54:15 Matlab Exp $
%       Status       : Ready ($Source: /home.others/Matlab/Matlab/radial/RCS/r2rdist.m,v $)


% Swap functions R2RDIST and RDIST2R for debugging ?
if exist('SWAP_DISTFCN') == 0,
  SWAP_DISTFCN = 0;
end
if SWAP_DISTFCN,
  rd = rdist2r(r0,k,r,0);
  return
end


N  = size(r,2);       % number of points
kn = size(k,1);       % order of the polynom / 2

%%
 % Compute polynom
 %   C(r) = k(1)*(r^2-r0^2) + k(2)*(r^4-r0^4) + ...
 %%
ex = 2*(1:kn)';
C = k'*( (ones(kn,1)*r).^(ex*ones(1,N)) - ((ones(kn,1)*r0).^ex)*ones(1,N) );

%%
 % Compute
 %   rd = r*(1+C(r)).
 %%
rd = r.*(1+C);

return
